from django.db import models
from django.utils.translation import gettext_lazy as _
from django.utils.translation import pgettext_lazy

from . import managers


class Operation(models.Model):
    slug = models.CharField(max_length=32, verbose_name=_('slug'), unique=True)

    def natural_key(self):
        return [self.slug]

    def __str__(self):
        return str(self._registry.get(self.slug, self.slug))

    def export_json(self):
        return {'slug': self.slug}

    @property
    def name(self):
        return str(self)

    @classmethod
    def register(cls, name, slug):
        cls._registry[slug] = name
        return cls(slug=slug)

    _registry = {}

    objects = managers.OperationManager()


Operation._meta.natural_key = ['slug']


ADMIN_OP = Operation.register(name=pgettext_lazy('permission', 'Management'), slug='admin')
CHANGE_OP = Operation.register(name=pgettext_lazy('permission', 'Change'), slug='change')
DELETE_OP = Operation.register(name=pgettext_lazy('permission', 'Delete'), slug='delete')
ADD_OP = Operation.register(name=pgettext_lazy('permission', 'Add'), slug='add')
VIEW_OP = Operation.register(name=pgettext_lazy('permission', 'View'), slug='view')
SEARCH_OP = Operation.register(name=pgettext_lazy('permission', 'Search'), slug='search')
